@@ -391,7 +391,7 @@ class CurveBuilder:
             if orientation in (Orientation.UP, Orientation.RIGHT, Orientation.DOWN, Orientation.LEFT):
                 curves.append(Line(self.id_provider(), points[ii], points[ii + 1]))
             else:
-                curves.append(Arc(self.id_provider(), orientation, points[0],
+                curves.append(Arc(self.id_provider(), orientation, points[ii],
                             Vector2(abs(points[ii + 1].x - points[ii].x) * 2, abs(points[ii + 1].y - points[ii].y) * 2))
                               )
         return curves
@@ -400,7 +400,7 @@ class CurveBuilder:
         curves = []
         # A Cubic Bezier requires 4 control points, so operate in blocks of 4 (re-using the last each time)
         for ii in range(0, len(points) - 3, 3):
-            curves.append(CubicBezier(self.id_provider(), points[ii:ii+3]))
+            curves.append(CubicBezier(self.id_provider(), points[ii:ii+4]))
         return curves
 
     def curves_from_temp_next_points(self, next_points: List[Vector2]):
